Router

Struct Router 

pub struct Router { /* private fields */ }

Implementations

Source

impl Router

pub fn new() -> Self

Construct a new, empty Router.

let router = Router::new();

Equivalent to Router::default().

pub fn add<R: Into<Route>>(&mut self, route: R)

Add a new route to a Router, matching both a Method and a Pattern. Any value that implements Into<Route> may be provided to route.

For example, to match a Get request to /users:

router.route((Method::GET, "/users", |_| {
    // [...]
}));
pub fn route<R: Into<Route>>(&mut self, route: R)

👎Deprecated since 0.0.7:

use Router::add instead

pub fn find(&self, method: &Method, uri: &str) -> Option<&Route>